from .utils import get_qol_eq5d3l_model_name, get_qol_sf12_model_name

QOL = "QOL"
QOL_VIEW = "QOL_VIEW"
QOL_SUPER = "QOL_SUPER"

edc_qol_codenames = []


for model in [get_qol_eq5d3l_model_name(), get_qol_sf12_model_name()]:
    app_name, model_name = model.split(".")
    for prefix in ["add", "change", "view", "delete"]:
        edc_qol_codenames.append(f"{app_name}.{prefix}_{model_name}")
    edc_qol_codenames.append(f"{app_name}.view_historical{model_name}")
edc_qol_codenames.sort()



# Generated by Django 3.2.6 on 2021-09-23 22:21

import _socket
from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_sites.models
import edc_utils.date
import simple_history.models
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.CreateModel(
            name="HistoricalEq5d3l",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "mobility",
                    models.CharField(
                        choices=[
                            ("no_problems_in_walking", "I have no problems in walking about"),
                            (
                                "some_problems_in_walking",
                                "I have some problems in walking about",
                            ),
                            ("confined_to_bed", "I am confined to bed"),
                        ],
                        max_length=45,
                        verbose_name="Mobility",
                    ),
                ),
                (
                    "self_care",
                    models.CharField(
                        choices=[
                            (
                                "no_problems_with_self_care",
                                "I have no problems with self-care",
                            ),
                            (
                                "problems_washing_dressing_myself",
                                "I have some problems washing or dressing myself",
                            ),
                            (
                                "unable_to_wash_dress_myself",
                                "I am unable to wash or dress myself",
                            ),
                        ],
                        max_length=45,
                        verbose_name="Self-care",
                    ),
                ),
                (
                    "usual_activities",
                    models.CharField(
                        choices=[
                            (
                                "no_problems_performing_usual_activities",
                                "I have no problems with performing my usual activities",
                            ),
                            (
                                "some_problems_performing_usual_activities",
                                "I have some problems with performing my usual activities",
                            ),
                            (
                                "unable_to_perform_usual_activities",
                                "I am unable to perform my usual activities",
                            ),
                        ],
                        help_text="Example. work, study, housework, family or leisure activities",
                        max_length=45,
                        verbose_name="Usual activities",
                    ),
                ),
                (
                    "pain_discomfort",
                    models.CharField(
                        choices=[
                            ("no_pain_discomfort", "I have no pain or discomfort"),
                            ("moderate_pain_discomfort", "I have moderate pain or discomfort"),
                            ("extreme_pain_discomfort", "I have extreme pain or discomfort"),
                        ],
                        max_length=45,
                        verbose_name="Pain / Discomfort",
                    ),
                ),
                (
                    "anxiety_depression",
                    models.CharField(
                        choices=[
                            ("not_anxious_depressed", "I am not anxious or depressed"),
                            (
                                "moderately_anxious_depressed",
                                "I am moderately anxious or depressed",
                            ),
                            (
                                "extremely_anxious_depressed",
                                "I am extremely anxious or depressed",
                            ),
                        ],
                        max_length=45,
                        verbose_name="Anxiety / Depression",
                    ),
                ),
                (
                    "health_today_score_slider",
                    models.CharField(
                        max_length=3, verbose_name="Visual score for how your health is TODAY"
                    ),
                ),
                (
                    "health_today_score_confirmed",
                    models.IntegerField(
                        help_text="This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="<B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.",
                    ),
                ),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical EuroQol EQ-5D-3L Instrument",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="Eq5d3l",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "mobility",
                    models.CharField(
                        choices=[
                            ("no_problems_in_walking", "I have no problems in walking about"),
                            (
                                "some_problems_in_walking",
                                "I have some problems in walking about",
                            ),
                            ("confined_to_bed", "I am confined to bed"),
                        ],
                        max_length=45,
                        verbose_name="Mobility",
                    ),
                ),
                (
                    "self_care",
                    models.CharField(
                        choices=[
                            (
                                "no_problems_with_self_care",
                                "I have no problems with self-care",
                            ),
                            (
                                "problems_washing_dressing_myself",
                                "I have some problems washing or dressing myself",
                            ),
                            (
                                "unable_to_wash_dress_myself",
                                "I am unable to wash or dress myself",
                            ),
                        ],
                        max_length=45,
                        verbose_name="Self-care",
                    ),
                ),
                (
                    "usual_activities",
                    models.CharField(
                        choices=[
                            (
                                "no_problems_performing_usual_activities",
                                "I have no problems with performing my usual activities",
                            ),
                            (
                                "some_problems_performing_usual_activities",
                                "I have some problems with performing my usual activities",
                            ),
                            (
                                "unable_to_perform_usual_activities",
                                "I am unable to perform my usual activities",
                            ),
                        ],
                        help_text="Example. work, study, housework, family or leisure activities",
                        max_length=45,
                        verbose_name="Usual activities",
                    ),
                ),
                (
                    "pain_discomfort",
                    models.CharField(
                        choices=[
                            ("no_pain_discomfort", "I have no pain or discomfort"),
                            ("moderate_pain_discomfort", "I have moderate pain or discomfort"),
                            ("extreme_pain_discomfort", "I have extreme pain or discomfort"),
                        ],
                        max_length=45,
                        verbose_name="Pain / Discomfort",
                    ),
                ),
                (
                    "anxiety_depression",
                    models.CharField(
                        choices=[
                            ("not_anxious_depressed", "I am not anxious or depressed"),
                            (
                                "moderately_anxious_depressed",
                                "I am moderately anxious or depressed",
                            ),
                            (
                                "extremely_anxious_depressed",
                                "I am extremely anxious or depressed",
                            ),
                        ],
                        max_length=45,
                        verbose_name="Anxiety / Depression",
                    ),
                ),
                (
                    "health_today_score_slider",
                    models.CharField(
                        max_length=3, verbose_name="Visual score for how your health is TODAY"
                    ),
                ),
                (
                    "health_today_score_confirmed",
                    models.IntegerField(
                        help_text="This scale is numbered from 0 to 100. 100 means the <U>best</U> health you can imagine0 means the <U>worst</U> health you can imagine.",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="<B><font color='orange'>Interviewer</font></B>: please confirm the number on the scale indicated from above.",
                    ),
                ),
                ("report_datetime", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "EuroQol EQ-5D-3L Instrument",
                "verbose_name_plural": "EuroQol EQ-5D-3L Instrument",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]



from django.test import TestCase

from edc_qol.models import Sf12

from .mixins import TestCaseMixin


class TestSf12Model(TestCaseMixin, TestCase):
    def test_pass(self):
        Sf12()
        self.assertTrue(True)



from django.contrib import admin
from django.utils.html import format_html
from django_audit_fields.admin import audit_fieldset_tuple
from edc_model_admin.history import SimpleHistoryAdmin
from edc_model_admin.mixins import ModelAdminInstitutionMixin

from ..admin_site import edc_qol_admin
from ..forms import Sf12Form
from ..models import Sf12

additional_instructions = format_html(
    "<p>"
    "This survey asks for your views about your health. This information "
    "will help keep track of how you feel and how well you are able to do "
    "your usual activities. "
    "<b>Answer each question by choosing just one answer</b>. If you are "
    "unsure how to answer a question, please give the best answer you can."
    "</p>"
)

past_4w = "<u>past 4 weeks</u>"

any_following_problems = (
    "have you had any of the following problems with your work or other "
    "regular daily activities"
)

part2_description = (
    "The following questions are about activities you might do during a typical day. "
    "Does <u>your health now limit you</u> in these activities? If so, how much?"
)

part3_description = (
    f"During the {past_4w}, {any_following_problems} "
    "<u>as a result of your physical health</u>?"
)

part4_description = (
    f"During the {past_4w}, {any_following_problems} "
    "<u>as a result of any emotional problems</u> (such as feeling depressed or anxious)?"
)

part6_description = (
    "<p>"
    f"These questions are about how you have been feeling during the {past_4w}. "
    "For each question, please give the one answer that comes closest to the "
    "way you have been feeling."
    "</p>"
    "<p>"
    f"How much of the time during the {past_4w}..."
    "</p>"
)


def sf12_fieldsets():
    return [
        (
            "Part 1: General health",
            {"fields": ("general_health",)},
        ),
        (
            "Part 2: Activities limited by health",
            {
                "description": format_html(part2_description),
                "fields": (
                    "moderate_activities_now_limited",
                    "climbing_stairs_now_limited",
                ),
            },
        ),
        (
            "Part 3: Physical health problems (last 4 weeks)",
            {
                "description": format_html(part3_description),
                "fields": (
                    "accomplished_less_physical_health",
                    "work_limited_physical_health",
                ),
            },
        ),
        (
            "Part 4: Emotional problems (last 4 weeks)",
            {
                "description": format_html(part4_description),
                "fields": (
                    "accomplished_less_emotional",
                    "work_less_carefully_emotional",
                ),
            },
        ),
        (
            "Part 5: Pain (last 4 weeks)",
            {"fields": ("pain_interfere_work",)},
        ),
        (
            "Part 6: Feeling (last 4 weeks)",
            {
                "description": format_html(part6_description),
                "fields": (
                    "felt_calm_peaceful",
                    "felt_lot_energy",
                    "felt_down",
                ),
            },
        ),
        (
            "Part 7: Social activities (last 4 weeks)",
            {"fields": ("social_activities_interfered",)},
        ),
    ]


def sf12_radio_fields():
    return {
        "accomplished_less_emotional": admin.VERTICAL,
        "accomplished_less_physical_health": admin.VERTICAL,
        "climbing_stairs_now_limited": admin.VERTICAL,
        "felt_calm_peaceful": admin.VERTICAL,
        "felt_down": admin.VERTICAL,
        "felt_lot_energy": admin.VERTICAL,
        "general_health": admin.VERTICAL,
        "moderate_activities_now_limited": admin.VERTICAL,
        "pain_interfere_work": admin.VERTICAL,
        "social_activities_interfered": admin.VERTICAL,
        "work_less_carefully_emotional": admin.VERTICAL,
        "work_limited_physical_health": admin.VERTICAL,
    }


@admin.register(Sf12, site=edc_qol_admin)
class Sf12Admin(ModelAdminInstitutionMixin, SimpleHistoryAdmin):

    form = Sf12Form

    fieldsets = (
        (None, {"fields": ("subject_identifier", "report_datetime")}),
        *sf12_fieldsets(),
        audit_fieldset_tuple,
    )

    radio_fields = sf12_radio_fields()



from copy import deepcopy

from django.test import TestCase
from edc_utils import get_utcnow

from edc_qol.constants import (
    NO_PAIN_DISCOMFORT,
    NO_PROBLEM_SELF_CARE,
    NO_PROBLEM_USUAL_ACTIVITIES,
    NO_PROBLEM_WALKING,
    NOT_ANXIOUS_DEPRESSED,
)


class TestCaseMixin(TestCase):
    def setUp(self):
        self.subject_identifier = "1234"
        self.data = dict(
            subject_identifier=self.subject_identifier, report_datetime=get_utcnow()
        )

    def get_best_case_patient_history_data(self):
        data = deepcopy(self.data)
        data.update(
            {
                "anxiety_depression": NOT_ANXIOUS_DEPRESSED,
                "mobility": NO_PROBLEM_WALKING,
                "pain_discomfort": NO_PAIN_DISCOMFORT,
                "self_care": NO_PROBLEM_SELF_CARE,
                "usual_activities": NO_PROBLEM_USUAL_ACTIVITIES,
            }
        )
        return data
